"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = require("node-fetch");
const endpoints = require("./endpoints");
async function getState(rawCookie) {
    const cookie = `.ROBLOSECURITY=${rawCookie};`;
    const authReq = await node_fetch_1.default(endpoints.AUTHENTICATED, {
        headers: {
            Cookie: cookie,
        },
    });
    if (authReq.status !== 200) {
        throw new Error("Unable to log in with provided cookie");
    }
    const userId = (await authReq.json()).id;
    const csrfReq = await node_fetch_1.default(endpoints.LOGOUT, {
        method: "POST",
        headers: {
            Cookie: cookie,
        },
    });
    const csrfToken = csrfReq.headers.get("x-csrf-token");
    if (!csrfToken) {
        throw new Error("Unable to determine CSRF token");
    }
    return {
        headers: {
            Cookie: cookie,
            "X-CSRF-TOKEN": csrfToken,
        },
        userId,
    };
}
exports.default = getState;
//# sourceMappingURL=state.js.map